<?php

/**
 * @file
 * Provides helper functions for cultura_discussion_install().
 */

/**
 * Create the Questionnaire configuration content type.
 */
function cultura_discussion_create_discussion_content_type() {
  $type = array(
    'type' => CULTURA_DISCUSSION_NODE_TYPE,
    'name' => st('Discussion'),
    'base' => 'node_content',
    'description' => st("Use <em>discussions</em> for introducing topics which students may discuss."),
    'custom' => 1,
    'modified' => 1,
    'locked' => 0,
  );
  $type = node_type_set_defaults($type);
  node_type_save($type);
  node_add_body_field($type);

  $rdf_mapping = array(
    'type' => 'node',
    'bundle' => CULTURA_DISCUSSION_NODE_TYPE,
    'mapping' => array(
      'rdftype' => array('foaf:Document'),
    ),
  );
  rdf_mapping_save($rdf_mapping);
  // Don't display date and author information for "Exchange" nodes by default.
  variable_set('node_submitted_' . CULTURA_DISCUSSION_NODE_TYPE, FALSE);

  // Comment settings.
  variable_set('comment_default_mode_' . CULTURA_DISCUSSION_NODE_TYPE, COMMENT_MODE_FLAT);
  variable_set('comment_default_per_page_' . CULTURA_DISCUSSION_NODE_TYPE, 50);
  variable_set('comment_' . CULTURA_DISCUSSION_NODE_TYPE, COMMENT_NODE_OPEN);
  variable_set('comment_form_location_' . CULTURA_DISCUSSION_NODE_TYPE, COMMENT_FORM_BELOW);
  variable_set('comment_preview_' . CULTURA_DISCUSSION_NODE_TYPE, FALSE);
  variable_set('comment_subject_field_' . CULTURA_DISCUSSION_NODE_TYPE, FALSE);

  // We already created the field in field in cultura_questionnaire, only need
  // to create the instance.

  $help = st('Select the category for this exchange.');
  $instance = array(
    'field_name' => CULTURA_QUESTIONNAIRE_FIELD_QUESTION_TYPE,
    'entity_type' => 'node',
    'label' => 'Question type',
    'bundle' => CULTURA_DISCUSSION_NODE_TYPE,
    'description' => $help,
    'required' => TRUE,
    'widget' => array(
      'type' => 'options_select',
      'weight' => -10,
    ),
    'display' => array(
      'default' => array(
        'type' => 'hidden',
      ),
      'teaser' => array(
        'type' => 'hidden',
      ),
    ),
  );
  field_create_instance($instance);

  // Create Double Textarea field to hold answer sets (one for each language).
  $field = array(
    'field_name' => CULTURA_DISCUSSION_FIELD_ANSWERS,
    'type' => 'double_field',
    'settings' => array(
      'first' => array(
        'type' => 'text',
      ),
      'second' => array(
        'type' => 'text',
      ),
    ),
    'columns' => array(
      'first' => array(
        'type' => 'text',
        'size' => 'big',
      ),
      'second' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
  );
  field_create_field($field);

  $instance = array(
    'label' => 'Answers',
    'widget' => array(
      'weight' => '8',
      'type' => 'textarea_&_textarea',
      'module' => 'double_field',
    ),
    'display' => array(
      'default' => array(
        'settings' => array(
          'first' => array(
            'hidden' => 0,
            'format' => '_none',
            'prefix' => '',
            'suffix' => ': ',
          ),
          'second' => array(
            'hidden' => 0,
            'format' => '_none',
            'prefix' => '',
            'suffix' => '',
          ),
        ),
        'weight' => 12,
      ),
      'teaser' => array(
        'type' => 'hidden',
        'settings' => array(),
        'weight' => 0,
      ),
    ),
    'required' => 0,
    'description' => 'Introduce the questionnaire (in each language).',
    'field_name' => CULTURA_DISCUSSION_FIELD_ANSWERS,
    'entity_type' => 'node',
    'bundle' => CULTURA_DISCUSSION_NODE_TYPE,
  );
  field_create_instance($instance);

  // Create and attach Tags field for free-tagging taxonomy.
  $field = array(
    'field_name' => CULTURA_TAGS,
    'type' => 'taxonomy_term_reference',
    'settings' => array(
      'allowed_values' => array(
        array(
          'vocabulary' => CULTURA_TAGS,
        ),
      ),
    ),
  );
  field_create_field($field);

  $help = st('List words or phrases you associate with this content, separated by commas.');
  $instance = array(
    'field_name' => CULTURA_TAGS,
    'entity_type' => 'node',
    'bundle' => CULTURA_DISCUSSION_NODE_TYPE,
    'label' => 'Tags',
    'description' => $help,
    'widget' => array(
      'weight' => '2',
      'type' => 'taxonomy_autocomplete',
      'module' => 'taxonomy',
      'active' => 0,
      'settings' => array(
        'size' => 60,
        'autocomplete_path' => 'taxonomy/autocomplete',
      ),
    ),
    'display' => array(
      'default' => array(
        'label' => 'inline',
        'weight' => '10',
      ),
      'teaser' => array(
        'label' => 'inline',
        'type' => 'hidden',
        'weight' => '1',
        'settings' => array(),
      ),
    ),
    'default_value' => NULL,
  );
  field_create_instance($instance);

  // Add nodereference to Questionnaire Builder.
  // The field was already created in Cultura Questionnaire.
  $instance = array(
    'field_name' => CULTURA_QUESTIONNAIRE_FIELD_QUESTIONNAIRE,
    'entity_type' => 'node',
    'bundle' => CULTURA_DISCUSSION_NODE_TYPE,
    'label' => 'Questionnaire builder',
    'widget' => array(
      'weight' => '31',
      'type' => 'node_reference_autocomplete',
      'module' => 'node_reference',
      'active' => 1,
      'settings' => array(
        'autocomplete_match' => 'starts_with',
        'size' => '60',
        'autocomplete_path' => 'node_reference/autocomplete',
      ),
    ),
    'display' => array(
      'default' => array(
        'label' => 'inline',
        'type' => 'hidden',
        'weight' => '1',
      ),
      'teaser' => array(
        'type' => 'hidden',
        'label' => 'above',
        'settings' => array(),
        'weight' => 0,
      ),
    ),
    'required' => 1,
    'default_value' => NULL,
  );
  field_create_instance($instance);
}

/**
 * Update shortcut sets.
 */
function cultura_discussion_configure_shortcuts() {
  $set_1 = shortcut_set_load('shortcut-set-1');
  $link = array();
  $link['link_title'] = t('Create discussion topic');
  $link['link_path'] = $link['router_path'] = 'node/add/' . drupal_html_class(CULTURA_DISCUSSION_NODE_TYPE);
  $link['weight'] = -20;
  $set_1->links[] = $link;
  shortcut_set_save($set_1);
}
